hash

package
v0.0.0-...-f70127e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2025 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func HMAC_SHA_512_256

func HMAC_SHA_512_256(data []byte, tag string) ([]byte, error)

Hash data using HMAC-SHA-512/256. This algorithm is fast on 64-bit machines and immune to length-extension attacks. The tag signifies the purpose of the hash and ensures that different purposes produce different hashes even with the same data.

func Hash

func Hash(data []byte, h hash.Hash) ([]byte, error)

Hash the data using the given Hash

func SHA256

func SHA256(data []byte) ([]byte, error)

Hash data using the SHA-256 algorithm

func SHA512

func SHA512(data []byte) ([]byte, error)

Hash data using the SHA-512 algorithm

Types

This section is empty.

Jump to