hmac

package
v0.0.0-...-f70127e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 17, 2025 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Generate

func Generate(data []byte, key []byte) []byte

Generates a symmetric signature using a shared secret key

func Verify

func Verify(data, givenMAC []byte, key []byte) bool

Securely check the givenMAC against the data with the shared secret key

Types

This section is empty.

Jump to