Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HMAC_SHA_512_256 ¶
Hash data using HMAC-SHA-512/256. This algorithm is fast on 64-bit machines and immune to length-extension attacks. The tag signifies the purpose of the hash and ensures that different purposes produce different hashes even with the same data.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.